@@ -107,10 +107,10 @@
 #include	<unistd.h>
 #include	<string.h>
 #include	<stdlib.h>
+#include	<limits.h>
 
 #include	"portability.h"
 #include	"pbs_ifl.h"
-#include        "pbs_version.h"
 #include        "mcom.h"
 #include        "cmds.h"
   
@@ -131,7 +131,7 @@ extern int MXMLCreateE(mxml_t **,char *);
 extern int MXMLAddE(mxml_t *,mxml_t *);
 extern int MXMLSetVal(mxml_t *,char *);
 extern int MXMLDestroyE(mxml_t **);
-extern int MXMLToString(mxml_t *,char *,int,int *,mbool_t);
+extern int MXMLToXString(mxml_t *,char **,int *,int, char **,mbool_t);
 
 /* END prototypes */
 
@@ -358,7 +358,7 @@ int main(
   extern int	 optind;
   char	       **pa;
   struct batch_status *pbstat;
-  int	flag = DOWN;
+  int	flag = ALLI;
 
   /* get default server, may be changed by -s option */
 
@@ -438,7 +438,7 @@ int main(
         if ((optarg != NULL) && !strcmp(optarg,"version"))
           {
           fprintf(stderr,"version: %s\n",
-            PBS_VERSION);
+            PACKAGE_VERSION);
 
           exit(0);
           }
@@ -638,7 +638,8 @@ int main(
         {
         struct attrl *pat;
 
-        char tmpBuf[400000];
+        char *tmpBuf=NULL, *tail=NULL;
+        int  bufsize;
 
         mxml_t *DE;
         mxml_t *NE;
@@ -671,7 +672,7 @@ int main(
             }
           }    /* END for (pbstat) */
 
-        MXMLToString(DE,tmpBuf,sizeof(tmpBuf),NULL,TRUE);
+        MXMLToXString(DE,&tmpBuf,&bufsize,INT_MAX,&tail,TRUE);
 
         MXMLDestroyE(&DE);
 
