@@ -96,13 +96,16 @@
 #include "cmds.h"
 #include "mcom.h"
 
-#include "pbs_version.h"
 
 #include <pwd.h>
+#include <limits.h>
 
 #if	TCL_QSTAT
 #include <sys/stat.h>
 #include <tcl.h>
+#if	TCLX
+#include <tclExtend.h>
+#endif
 #endif
 
 static void states();
@@ -132,13 +135,16 @@ extern int MXMLCreateE(mxml_t **,char *);
 extern int MXMLAddE(mxml_t *,mxml_t *);
 extern int MXMLSetVal(mxml_t *,char *);
 extern int MXMLDestroyE(mxml_t **);
-extern int MXMLToString(mxml_t *,char *,int,int *,mbool_t);
+extern int MXMLToXString(mxml_t *,char **,int *,int, char **,mbool_t);
 
 /* END prototypes */
 
 /* globals */
 
 mbool_t DisplayXML = FALSE;
+#define maxlinesize 65536
+int   linesize = 77;
+
 
 /* END globals */
 
@@ -188,26 +194,6 @@ int istrue(
 
 
 
-static void maxstate(
-
-  char *string, /* I */
-  int  *cnt)
-
-  {
-  char *ptr;
-
-  *cnt = 0;
-
-  for (ptr = strchr(string,':');ptr != NULL;ptr = strchr(ptr + 1,':'))
-    {
-    *cnt = MAX(*cnt,(int)strtol(ptr + 1,NULL,10));
-    }
-
-  return;
-  }
-
-
-
 
 static void states(
 
@@ -322,7 +308,7 @@ void prt_attr(
 
   while (c != NULL) 
     {
-    if ((l = strlen(c)) + start < 78) 
+    if ((l = strlen(c)) + start < linesize) 
       {
       printf("%s", 
         c);
@@ -342,7 +328,7 @@ void prt_attr(
         {
         putchar(*c++);
 
-        if (++start > 78) 
+        if (++start > linesize) 
           {
           start = 8;
 
@@ -402,7 +388,7 @@ static char *findattrl(
 
 
 #define NAMEL   16  /* printf of jobs, queues, and servers */
-#define OWNERL  16  /* printf of jobs */
+#define OWNERL  15  /* printf of jobs */
 #define TIMEUL  8   /* printf of jobs */
 #define STATEL  1   /* printf of jobs */
 #define LOCL    15  /* printf of jobs */
@@ -418,15 +404,12 @@ static char *findattrl(
 
 static void prt_nodes(
 
-  char *nodes,   /* I */
-  int   option)  /* I */
+  char *nodes)   /* I */
 
   {
   int   i;
   char *stp;
 
-  int   linesize;
-
   char  linebuf[65536];
 
   if ((nodes == NULL) || (*nodes == '\0'))
@@ -436,15 +419,6 @@ static void prt_nodes(
     return;
     }
 
-  if (option & ALT_DISPLAY_o) 
-    {
-    linesize = sizeof(linebuf);        
-    }
-  else
-    {
-    linesize = 77;
-    }
-
   i = 0;
 
   stp = nodes;
@@ -774,14 +748,14 @@ static void altdsp_statjob(
         usecput ? eltimecpu : eltimewal);
       }
 
-    if (!(alt_opt & ALT_DISPLAY_o)) 
+    if (linesize < maxlinesize) 
       printf("\n");
 
     if (alt_opt & ALT_DISPLAY_n) 
       {
       /* print assigned nodes */
 
-      prt_nodes(exechost,alt_opt);
+      prt_nodes(exechost);
       }
 
     if (alt_opt & ALT_DISPLAY_s) 
@@ -854,8 +828,8 @@ static void altdsp_statque(
   struct attrl *pat;
 
   printf("\nserver: %s\n\n", serv);
-  printf("Queue            Memory CPU Time Walltime Node Run Que Lm  State\n");
-  printf("---------------- ------ -------- -------- ---- --- --- --  -----\n");
+  printf("Queue            Memory CPU Time Walltime Node  Run Que Lm  State\n");
+  printf("---------------- ------ -------- -------- ----  --- --- --  -----\n");
 
   while (pstat != NULL) 
     {
@@ -918,8 +892,8 @@ static void altdsp_statque(
 		pstat = pstat->next;
 	}
 
-  printf("                                               --- ---\n");
-  printf("                                               %3d %3d\n", 
+  printf("                                               ----- -----\n");
+  printf("                                               %5d %5d\n", 
     tot_jrun, 
     tot_jque);
 
@@ -1001,9 +975,8 @@ void display_statjob(
     if (prtheader) 
       {
       /* display summary header */
-
-      printf("Job id              Name             User             Time Use S Queue\n");
-      printf("------------------- ---------------- ---------------- -------- - -----\n");
+      printf("Job id              Name             User            Time Use S Queue\n");
+      printf("------------------- ---------------- --------------- -------- - -----\n");
       }
     }    /* END if (!full) */
 
@@ -1248,9 +1221,10 @@ void display_statjob(
 
   if (DisplayXML == TRUE)
     {
-    char tmpBuf[400000];
+    char *tmpBuf=NULL, *tail=NULL;
+    int  bufsize;
 
-    MXMLToString(DE,tmpBuf,sizeof(tmpBuf),NULL,TRUE);
+    MXMLToXString(DE,&tmpBuf,&bufsize,INT_MAX,&tail,TRUE);
 
     MXMLDestroyE(&DE);
 
@@ -1264,7 +1238,7 @@ void display_statjob(
 
 
 #define MINNUML    3
-#define MAXNUML    4
+#define MAXNUML    5
 #define TYPEL     10
 
 void display_statque(
@@ -1292,33 +1266,8 @@ void display_statque(
   char *type;
   char format[80];
 
-  int  MaxCat;
-  int  qmax;
-  int  NUML;
+  int  NUML=5;
 
-  /* determine number of nodes in each category */
-
-  MaxCat = 0;
-
-  p = status;
-
-  while (p != NULL)
-    {
-    if ((p->attribs != NULL) && (p->attribs->value != NULL))
-      maxstate(p->attribs->value,&qmax);
-
-    MaxCat = MAX(MaxCat,qmax);
-
-    p = p->next;
-    }
-
-  if (MaxCat >= 1000)
-    NUML = 4;
-  else
-    NUML = 3;
-
-  NUML = MAX(MINNUML,NUML);
-  NUML = MIN(MAXNUML,NUML);
 
   sprintf(format,"%%-%ds %%%ds %%%ds %%%ds %%%ds %%%ds %%%ds %%%ds %%%ds %%%ds %%%ds %%-%ds\n", 
     NAMEL, 
@@ -1336,16 +1285,8 @@ void display_statque(
 
   if (!full && prtheader) 
     {
-    if (NUML == 3)
-      {
-      printf("Queue            Max Tot Ena Str Que Run Hld Wat Trn Ext Type\n");
-      printf("---------------- --- --- --- --- --- --- --- --- --- --- ----------\n");
-      }
-    else 
-      {
-      printf("Queue            Max  Tot  Ena Str Que  Run  Hld  Wat  Trn  Ext  Type\n");
-      printf("---------------- ---- ---- --- --- ---- ---- ---- ---- ---- ---- ----------\n");
-      }
+    printf(format,"Queue","Max","Tot","Ena","Str","Que","Run","Hld","Wat","Trn","Ext","T");
+    printf(format,"----------------","---","---","---","---","---","---","---","---","---","---","-");
     }
 
   p = status;
@@ -1452,16 +1393,9 @@ void display_statque(
             } 
           else if (strcmp(a->name,ATTR_qtype) == 0) 
             {
-            l = strlen(a->value);
-
-            if (l > TYPEL) 
-              {
-              c = a->value + TYPEL;
-
-              *c = '\0';
-              }
-
             type = a->value;
+
+            *(type +1) = '\0';
             }
           }
 
@@ -1537,8 +1471,8 @@ void display_statserver(
 
   if (!full && prtheader) 
     {
-    printf("Server           Max Tot Que Run Hld Wat Trn Ext Status\n");
-    printf("---------------- --- --- --- --- --- --- --- --- ----------\n");
+    printf(format,"Server","Max","Tot","Que","Run","Hld","Wat","Trn","Ext","Status");
+    printf(format,"----------------","---","---","---","---","---","---","---","---","----------");
     }
 
     p = status;
@@ -1661,9 +1595,7 @@ tcl_init()
 {
 	struct	passwd	*pw;
 	uid_t		uid;
-	struct	stat	sb;
-	struct	batch_status	*bp;
-	int		i, ret = 1;
+	struct  stat    sb;
 
 	uid = getuid();
 	pw = getpwuid(uid);
@@ -1805,8 +1737,7 @@ void tcl_run(
 int main(
 
   int    argc,
-  char **argv,
-  char **envp)
+  char **argv)
 
   {
   int c;
@@ -1814,7 +1745,9 @@ int main(
   int any_failed=0;
   extern char *optarg;
   char *conflict = "qstat: conflicting options.\n";
+#if (TCL_QSTAT == 0)
   char *pc;
+#endif
   int located = FALSE;
 
   char option[3];
@@ -2025,7 +1958,7 @@ int main(
         if ((optarg != NULL) && !strcmp(optarg,"version"))
           {
           fprintf(stderr,"version: %s\n",
-            PBS_VERSION);
+            PACKAGE_VERSION);
 
           exit(0);
           }
@@ -2150,23 +2083,29 @@ int main(
     errflg++;
     }
 
-  if ((alt_opt & ALT_DISPLAY_o) && !(alt_opt & ALT_DISPLAY_n))
+  if ((alt_opt & ALT_DISPLAY_o) && !((alt_opt & ALT_DISPLAY_n)||(f_opt)))
     {
     fprintf(stderr,conflict);
 
     errflg++;
     }
 
+  if (alt_opt & ALT_DISPLAY_o) 
+    {
+    linesize = maxlinesize;
+    alt_opt &= ~ALT_DISPLAY_o;
+    }
+
 #endif /* PBS_NO_POSIX_VIOLATION */
 
   if (errflg) 
     {
     static char usage[]="usage: \n\
-qstat [-f] [-W site_specific] [ job_identifier... | destination... ]\n\
+qstat [-f] [-1] [-W site_specific] [ job_identifier... | destination... ]\n\
 qstat [-a|-i|-r|-e] [-u user] [-n [-1]] [-s] [-G|-M] [-R] [job_id... | destination...]\n\
-qstat -Q [-f] [-W site_specific] [ destination... ]\n\
+qstat -Q [-f [-1]] [-W site_specific] [ destination... ]\n\
 qstat -q [-G|-M] [ destination... ]\n\
-qstat -B [-f] [-W site_specific] [ server_name... ]\n";
+qstat -B [-f [-1]] [-W site_specific] [ server_name... ]\n";
 
     fprintf(stderr,usage);
 
