@@ -97,15 +97,20 @@
 
 extern long *log_event_mask;
 
+/* set this to non-zero in calling app if errors go to stderr */
+extern int   chk_file_sec_stderr;
+
+
 extern void log_close A_((int));
 extern void log_err A_((int,char *,char *));
 extern void log_event A_((int,int,char *,char *));
 extern int  log_open A_((char *,char *));
 extern void log_record A_((int,int,char *,char *));
+extern void log_roll A_((int));
+extern long log_size A_((void));
 extern char log_buffer[LOG_BUF_SIZE];
 
 extern int  chk_file_sec A_((char *,int,int,int,int));
-extern int  chk_path_sec A_((char *,int,int,int,int));
 extern int  setup_env A_((char *));
 
 
