@@ -123,6 +123,18 @@ ATTR_jobstatrate,
 ATTR_polljobs,
 ATTR_downonerror,
 ATTR_jobnanny,
+ATTR_ownerpurge,
+ATTR_qcqlimits,
 ATTR_momjobsync,
 ATTR_maildomain,
 ATTR_pbsversion,
+ATTR_killdelay,
+ATTR_acllogic,
+ATTR_aclgrpslpy,
+ATTR_keepcompleted,
+ATTR_submithosts,
+ATTR_allownodesubmit,
+ATTR_servername,
+ATTR_autonodenp,
+ATTR_logfilemaxsize,
+ATTR_logfilerolldepth,
