@@ -127,7 +127,7 @@ int resc_access_perm;
 int comp_resc_gt;	/* count of resources compared > */
 int comp_resc_eq;	/* count of resources compared = */
 int comp_resc_lt;	/* count of resources compared < */
-int comp_resc_nc;	/* count of resources not compared  */
+int comp_resc_nc;	/* count of resources not compared */
 
 extern resource_def svr_resc_def[];
 extern int	    svr_resc_size;
@@ -243,13 +243,15 @@ int decode_resc(
  *		 <0 if some resource entry had an encode error.
  */
 
-int encode_resc(attr, phead, atname, rsname, mode)
-	attribute	*attr;	  /* ptr to attribute to encode */
-	list_head	*phead;	  /* head of attrlist list */
-	char		*atname;   /* attribute name */
-	char		*rsname;   /* resource name, null on call */
-	int		 mode;	  /* encode mode */
-{
+int encode_resc(
+
+  attribute	*attr,	  /* ptr to attribute to encode */
+  tlist_head	*phead,	  /* head of attrlist list */
+  char		*atname,   /* attribute name */
+  char		*rsname,   /* resource name, null on call */
+  int		 mode)	  /* encode mode */
+
+  {
 	int	    dflt;
 	resource   *prsc;
 	int	    rc;
@@ -306,15 +308,17 @@ int encode_resc(attr, phead, atname, rsname, mode)
  *		>0 if error
  */
 
-int set_resc(old, new, op)
-	struct attribute *old;
-	struct attribute *new;
-	enum batch_op op;
-{
-	enum batch_op local_op;
-	resource *newresc;
-	resource *oldresc;
-	int	  rc;
+int set_resc(
+
+  struct attribute *old,
+  struct attribute *new,
+  enum batch_op     op)
+
+  {
+  enum batch_op local_op;
+  resource *newresc;
+  resource *oldresc;
+  int	  rc;
 
 	assert(old && new);
 
@@ -330,7 +334,6 @@ int set_resc(old, new, op)
 			/* add new resource to list */
 			oldresc = add_resource_entry(old,newresc->rs_defin);
 			if (oldresc == (resource *)0) {
-				log_err(-1,"set_resc","Unable to malloc space");
 				return (PBSE_SYSTEM);
 			}
 		}
@@ -355,13 +358,114 @@ int set_resc(old, new, op)
 
 		newresc = (resource *)GET_NEXT(newresc->rs_link);
 	}
-	old->at_flags |= ATR_VFLAG_SET | ATR_VFLAG_MODIFY;
-	return (0);
-}
+
+  old->at_flags |= ATR_VFLAG_SET | ATR_VFLAG_MODIFY;
+
+  return(0);
+  }
+
+
+
 
 /*
  * comp_resc - compare two attributes of type ATR_TYPE_RESR
  *
+ *      DANGER Will Robinson, DANGER
+ *
+ *      As you can see from the returns, this is different from the
+ *      at_comp model...
+ *
+ *      Returns: 0 if compare successful:
+ *                 sets comp_resc_gt to count of "greater than" compares
+ *                              attr > with
+ *                 sets comp_resc_eq to count of "equal to" compares
+ *                              attr == with
+ *                 sets comp_resc_lt to count of "less than" compares
+ *                              attr < with
+ *              -1 if error
+ */
+
+/* NOTE:  if IsQueueCentric is 0, enforce for every job attr set,
+          if IsQueueCentric is 1, enforce for every queue attr set
+          old default behavior was '1' */
+
+int comp_resc(
+
+  struct attribute *attr,  /* I queue's min/max attributes */
+  struct attribute *with)  /* I job's current requirements/attributes */
+
+  {
+  resource *atresc;
+  resource *wiresc;
+  int rc;
+
+  comp_resc_gt = 0;
+  comp_resc_eq = 0;
+  comp_resc_lt = 0;
+  comp_resc_nc = 0;
+
+  if ((attr == NULL) || (with == NULL))
+    {
+    /* FAILURE */
+
+    return(-1);
+    }
+
+  /* comparison is job centric */
+
+  /* NOTE:  this check only enforces attributes if the job specifies the
+            attribute.  If the queue has a min requirement of resource X
+            and the job has no value set for this resource, this routine
+            will not trigger comp_resc_lt */
+
+  wiresc = (resource *)GET_NEXT(with->at_val.at_list);
+
+  while (wiresc != NULL)
+    {
+    if ((wiresc->rs_value.at_flags & ATR_VFLAG_SET) &&
+       ((wiresc->rs_value.at_flags & ATR_VFLAG_DEFLT) == 0))
+      {
+      atresc = find_resc_entry(attr,wiresc->rs_defin);
+
+      if (atresc != NULL)
+        {
+        if (atresc->rs_value.at_flags & ATR_VFLAG_SET)
+          {
+          if ((rc = atresc->rs_defin->rs_comp(
+              &atresc->rs_value,
+              &wiresc->rs_value)) > 0)
+            {
+            comp_resc_gt++;
+            }
+          else if (rc < 0)
+            {
+            comp_resc_lt++;
+            }
+          else
+            {
+            comp_resc_eq++;
+            }
+          }
+        }
+      else
+        {
+        comp_resc_nc++;
+        }
+      }
+
+    wiresc = (resource *)GET_NEXT(wiresc->rs_link);
+    }  /* END while() */
+
+  return(0);
+  }  /* END comp_resc() */
+
+
+
+
+
+/*
+ * comp_resc2 - compare two attributes of type ATR_TYPE_RESR
+ *
  *	DANGER Will Robinson, DANGER
  *
  *	As you can see from the returns, this is different from the
@@ -377,66 +481,146 @@ int set_resc(old, new, op)
  *		-1 if error
  */
 
-int comp_resc(
+/* NOTE:  if IsQueueCentric is 0, enforce for every job attr set, 
+          if IsQueueCentric is 1, enforce for every queue attr set
+          old default behavior was '1' */
 
-  struct attribute *attr,
-  struct attribute *with)
+int comp_resc2(
+
+  struct attribute *attr,           /* I queue's min/max attributes */
+  struct attribute *with,           /* I job's current requirements/attributes */
+  int               IsQueueCentric, /* I */
+  char             *EMsg)           /* O (optional,minsize=1024) */
 
   {
   resource *atresc;
   resource *wiresc;
   int rc;
+  char *LimitName;
 
   comp_resc_gt = 0;
   comp_resc_eq = 0;
   comp_resc_lt = 0;
   comp_resc_nc = 0;
 
-  if ((attr == (attribute *)0) || (with == (attribute *)0))
+  if (EMsg != NULL)
+    EMsg[0] = '\0';
+
+  if ((attr == NULL) || (with == NULL))
     {
+    /* FAILURE */
+
     return(-1);
     }
 
-  wiresc = (resource *)GET_NEXT(with->at_val.at_list);
-
-  while (wiresc != (resource *)0) 
+  if (IsQueueCentric == 1)
     {
-    if ((wiresc->rs_value.at_flags & ATR_VFLAG_SET) &&
-       ((wiresc->rs_value.at_flags & ATR_VFLAG_DEFLT) == 0)) 
+    /* comparison is queue centric */
+
+    atresc = (resource *)GET_NEXT(attr->at_val.at_list);
+
+    while (atresc != NULL)
       {
-      atresc = find_resc_entry(attr,wiresc->rs_defin);
-
-      if (atresc != (resource *)0) 
+      if (atresc->rs_value.at_flags & ATR_VFLAG_SET) 
         {
-	if (atresc->rs_value.at_flags & ATR_VFLAG_SET)
-          {
-          if ((rc = atresc->rs_defin->rs_comp(
-              &atresc->rs_value,
-              &wiresc->rs_value)) > 0)
-            {
-            comp_resc_gt++;
-            }
-          else if (rc < 0)
-            {
-            comp_resc_lt++;
-            }
-          else
-            {
-            comp_resc_eq++;
-            }
-          } 
-        } 
-      else 
-        {	
-        comp_resc_nc++;
-        }
-      }
+        wiresc = find_resc_entry(with,atresc->rs_defin);
 
-    wiresc = (resource *)GET_NEXT(wiresc->rs_link);
-    }  /* END while() */
+        if (wiresc != NULL)
+          {
+          if ((wiresc->rs_value.at_flags & ATR_VFLAG_SET) &&
+              (wiresc->rs_value.at_flags & ATR_VFLAG_DEFLT))
+            {
+            if ((rc = atresc->rs_defin->rs_comp(
+                &atresc->rs_value,
+                &wiresc->rs_value)) > 0)
+              {
+              if ((EMsg != NULL) && (EMsg[0] == '\0'))
+                {
+                LimitName = atresc->rs_defin->rs_name;
+
+                sprintf(EMsg,"cannot satisfy queue min %s requirement",
+                  (LimitName != NULL) ? LimitName : "resource");
+                }
+
+              comp_resc_gt++;
+              }
+            else if (rc < 0)
+              {
+              comp_resc_lt++;
+              }
+            else
+              {
+              comp_resc_eq++;
+              }
+            }
+          }
+        else
+          {
+          comp_resc_nc++;
+          }
+        }
+
+      atresc = (resource *)GET_NEXT(atresc->rs_link);
+      }
+    }
+  else
+    {
+    /* comparison is job centric */
+
+    /* NOTE:  this check only enforces attributes if the job specifies the
+              attribute.  If the queue has a min requirement of resource X
+              and the job has no value set for this resource, this routine
+              will not trigger comp_resc_lt */
+
+    wiresc = (resource *)GET_NEXT(with->at_val.at_list);
+
+    while (wiresc != NULL) 
+      {
+      if ((wiresc->rs_value.at_flags & ATR_VFLAG_SET) &&
+         ((wiresc->rs_value.at_flags & ATR_VFLAG_DEFLT) == 0)) 
+        {
+        atresc = find_resc_entry(attr,wiresc->rs_defin);
+
+        if (atresc != NULL) 
+          {
+          if (atresc->rs_value.at_flags & ATR_VFLAG_SET)
+            {
+            if ((rc = atresc->rs_defin->rs_comp(
+                &atresc->rs_value,
+                &wiresc->rs_value)) > 0)
+              {
+              if ((EMsg != NULL) && (EMsg[0] == '\0'))
+                {
+                LimitName = atresc->rs_defin->rs_name;
+
+                sprintf(EMsg,"cannot satisfy queue min %s requirement",
+                  (LimitName != NULL) ? LimitName : "resource");
+                }
+
+              comp_resc_gt++;
+              }
+            else if (rc < 0)
+              {
+              comp_resc_lt++;
+              }
+            else
+              {
+              comp_resc_eq++;
+              }
+            } 
+          } 
+        else 
+          {	
+          comp_resc_nc++;
+          }
+        }
+
+      wiresc = (resource *)GET_NEXT(wiresc->rs_link);
+      }  /* END while() */
+    }
 
   return(0);
-  }  /* END comp_resc() */
+  }  /* END comp_resc2() */
 
 
 
@@ -567,7 +751,6 @@ resource *add_resource_entry (pattr, prdef)
 	}
 	new = (resource *)malloc(sizeof (resource));
 	if (new == (resource *)0) {
-		log_err(-1, "add_resource_entry", "unable to malloc space");
 		return ((resource *)0);
 	}
 	CLEAR_LINK(new->rs_link);
