@@ -171,59 +171,69 @@ int PNodeStateToString(
     return(-1);
     }
 
+  BufSize--;
+
   Buf[0] = '\0';
 
   if (SBM & (INUSE_DOWN))
     {
     if (Buf[0] != '\0')
-      strcat(Buf,",");
+      strncat(Buf,",",BufSize-strlen(Buf));
 
-    strcat(Buf,ND_down);
+    strncat(Buf,ND_down,BufSize-strlen(Buf));
     }
 
   if (SBM & (INUSE_OFFLINE))
     {
     if (Buf[0] != '\0')
-      strcat(Buf,",");
+      strncat(Buf,",",BufSize-strlen(Buf));
 
-    strcat(Buf,ND_offline);
+    strncat(Buf,ND_offline,BufSize-strlen(Buf));
     }
 
   if (SBM & (INUSE_JOB))
     {
     if (Buf[0] != '\0')
-      strcat(Buf,",");
+      strncat(Buf,",",BufSize-strlen(Buf));
 
-    strcat(Buf,ND_job_exclusive);
+    strncat(Buf,ND_job_exclusive,BufSize-strlen(Buf));
     }
 
   if (SBM & (INUSE_JOBSHARE))
     {
     if (Buf[0] != '\0')
-      strcat(Buf,",");
+      strncat(Buf,",",BufSize-strlen(Buf));
 
-    strcat(Buf,ND_job_sharing);
+    strncat(Buf,ND_job_sharing,BufSize-strlen(Buf));
     }
 
   if (SBM & (INUSE_BUSY))
     {
     if (Buf[0] != '\0')
-      strcat(Buf,",");
+      strncat(Buf,",",BufSize-strlen(Buf));
 
-    strcat(Buf,ND_busy);
+    strncat(Buf,ND_busy,BufSize-strlen(Buf));
     }
 
   if (SBM & (INUSE_RESERVE))
     {
     if (Buf[0] != '\0')
-      strcat(Buf,",");
+      strncat(Buf,",",BufSize-strlen(Buf));
 
-    strcat(Buf,ND_reserve);
+    strncat(Buf,ND_reserve,BufSize-strlen(Buf));
+    }
+
+  if (SBM & (INUSE_UNKNOWN))
+    {
+    if (Buf[0] != '\0')
+      strncat(Buf,",",BufSize-strlen(Buf));
+
+    strncat(Buf,ND_state_unknown,BufSize-strlen(Buf));
     }
 
   if (Buf[0] == '\0')
     {
-    strcat(Buf,ND_free);
+    strncpy(Buf,ND_free,BufSize);
     }
 
   return(0);
@@ -245,7 +255,7 @@ int PNodeStateToString(
 int encode_state(
 
   attribute *pattr,	/*struct attribute being encoded  */
-  list_head *ph,	/*head of a list of  "svrattrl"   */
+  tlist_head *ph,	/*head of a list of  "svrattrl"   */
 			/*structs which are to be returned*/
 
   char      *aname,	/*attribute's name		  */
@@ -326,7 +336,7 @@ int encode_state(
  
 int	encode_ntype(pattr, ph, aname, rname, mode)
 	attribute	 *pattr;	/*struct attribute being encoded  */
-	list_head	 *ph;		/*head of a list of  "svrattrl"   */
+	tlist_head	 *ph;		/*head of a list of  "svrattrl"   */
 					/*structs which are to be returned*/
 
 	char		 *aname;	/*attribute's name		  */
@@ -336,7 +346,6 @@ int	encode_ntype(pattr, ph, aname, rname, mode)
 {
         svrattrl *pal;
 	short	 ntype;
-	static	 char	*nt[] = { ND_cluster, ND_timeshared };
 
 	static   char	ntype_str[ MAX_ENCODE_BFR ];
 
@@ -348,10 +357,10 @@ int	encode_ntype(pattr, ph, aname, rname, mode)
 	
 	ntype = pattr->at_val.at_short & PBSNODE_NTYPE_MASK;
 	if (!ntype)
-	    strcpy( ntype_str, nt[0] );
+	    strcpy( ntype_str, ND_cluster );
 
 	else
-	    strcpy( ntype_str, nt[1] );
+	    strcpy( ntype_str, ND_timeshared );
 	
         pal = attrlist_create(aname,rname,(int)strlen(ntype_str)+1);
         if (pal == (svrattrl *)0)
@@ -386,7 +395,7 @@ int	encode_ntype(pattr, ph, aname, rname, mode)
 int encode_jobs(
 
   attribute *pattr,	/*struct attribute being encoded  */
-  list_head *ph,	/*head of a  list of "svrattrl"   */
+  tlist_head *ph,	/*head of a  list of "svrattrl"   */
 			/*structs which are to be returned*/
   char      *aname,	/*attribute's name		  */
   char      *rname,	/*resource's name (null if none)  */
@@ -654,6 +663,8 @@ void	free_prop_list( prop )
 }
 
 
+
+
 /*
  * set_node_state - the information in the "short" attribute, *new, is used to
  *		    update the information in the "short" attribute, *pattr.
@@ -661,21 +672,25 @@ void	free_prop_list( prop )
  *		    (SET,INCR,DECR)
  */
 
-int	set_node_state( pattr, new, op)
-	attribute	*pattr;		/*attribute gets modified    */
-	attribute	*new;		/*carries new, modifying info*/
-					/*that got decoded into 'new"*/
-	enum batch_op	 op;
-{
-	int	rc = 0;
+int set_node_state( 
 
-	assert( pattr && new && (new->at_flags & ATR_VFLAG_SET) );
+  attribute *pattr,		/*attribute gets modified    */
+  attribute *new,		/*carries new, modifying info*/
+				/*that got decoded into 'new"*/
+  enum batch_op op)
 
-	switch( op ) {
+  {
+  int rc = 0;
 
-	    case SET:
-	    pattr->at_val.at_short = new->at_val.at_short;
-	    break;
+  assert((pattr != NULL) && (new != NULL) && (new->at_flags & ATR_VFLAG_SET));
+
+  switch(op) 
+    {
+    case SET:
+
+      pattr->at_val.at_short = new->at_val.at_short;
+
+      break;
 
 	    case INCR:
 	    if(pattr->at_val.at_short && new->at_val.at_short == 0) {
@@ -929,17 +944,6 @@ int node_prop_list(
 
       /* update node with new attr_strings */
 
-      if (np->nd_prop != NULL)
-        {
-        /* NO-OP */
-
-        if (LOGLEVEL >= 1)
-          {
-          fprintf(stderr,"ERROR:  possible memory leak in node %s node_prop_list()\n",
-            np->nd_name);
-          }
-        }
-
       np->nd_prop = new->at_val.at_arst;
 
       /* update number of properties listed in node */
