@@ -134,6 +134,7 @@ static	tm_node_id	tm_jobndid = TM_ERROR_NODE;
 static	int		tm_momport = 0;
 static	int		local_conn = -1;
 static	int		init_done = 0;
+int *tm_conn = &local_conn;
 
 void	DIS_tcp_funcs();
 
@@ -438,6 +439,14 @@ static int localmom()
       return(-1);
       }
 
+#ifndef HAVE_POLL
+    if (sock >= FD_SETSIZE)
+      {
+      close(sock);
+      return(-1);
+      }
+#endif
+
     /* make sure data goes out */
  
     ltime.l_onoff = 1;
@@ -704,6 +713,9 @@ tm_spawn(argc, argv, envp, where, tid, event)
 	}
 
 	/* send envp strings across */
+	if (getenv("PBSDEBUG") != NULL)
+		if (diswcs(local_conn, "PBSDEBUG=1", strlen("PBSDEBUG=1")) != DIS_SUCCESS)
+			return TM_ENOTCONNECTED;
 	if (envp != NULL) {
 		for (i=0; (cp = envp[i]) != NULL; i++) {
 			if (diswcs(local_conn, cp, strlen(cp)) != DIS_SUCCESS)
@@ -1213,6 +1225,12 @@ int tm_poll(
 
 		node_table = (tm_node_id *)calloc(nnodes+1,
 				sizeof(tm_node_id));
+		if (node_table == NULL)
+		  {
+		  perror("Memory allocation failed");
+		  goto err;
+		  }
+
 		DBPRT(("%s: INIT nodes %d\n", id, nnodes))
 		for (i=0; i<nnodes; i++) {
 			node_table[i] = disrsi(local_conn, &ret);
