@@ -153,10 +153,12 @@ extern char  server_name[];
 
 extern struct server server;
 extern tlist_head svr_newnodes;
+extern int            SvrNodeCt;
 
 #define	SKIP_NONE	0
 #define	SKIP_EXCLUSIVE	1
 #define	SKIP_ANYINUSE	2
+#define SKIP_NONE_REUSE 3
 
 int hasprop(struct pbsnode *,struct prop *);
 void send_cluster_addrs(struct work_task *);
@@ -1792,7 +1794,7 @@ void is_request(
 
   /* node not listed in trusted ipaddrs list */
 
-  sprintf(log_buffer,"bad attempt to connect from %s (address not trusted)",
+  sprintf(log_buffer,"bad attempt to connect from %s (address not trusted - check entry in server_priv/nodes)",
     netaddr(addr));
 
   if (LOGLEVEL >= 2)
@@ -2228,7 +2230,9 @@ static int hasppn(
   int             free)      /* I */
 
   {
-  if ((free != SKIP_NONE) && (pnode->nd_nsnfree >= node_req))
+  if ((free != SKIP_NONE) && 
+      (free != SKIP_NONE_REUSE) && 
+      (pnode->nd_nsnfree >= node_req))
     {
     return(1);
     }
@@ -2251,7 +2255,7 @@ static int hasppn(
 
 static void mark(
 
-  struct pbsnode *pnode,
+  struct pbsnode *pnode,  /* I */
   struct prop    *props)
 
   {
@@ -2276,7 +2280,7 @@ static void mark(
     }
 
   return;
-  }
+  }  /* END mark() */
 
 
 
@@ -2318,10 +2322,17 @@ static int search(
     if (pnode->nd_state & INUSE_DELETED)
       continue;
 
-    if (pnode->nd_ntype  == NTYPE_CLUSTER) 
+    if (pnode->nd_ntype == NTYPE_CLUSTER) 
       {
       if (pnode->nd_flag != okay)
-        continue;
+        {
+        if ((skip != SKIP_NONE_REUSE) || (pnode->nd_flag != thinking))
+          {
+          /* allow node re-use if SKIP_NONE_REUSE is set */
+
+          continue;
+          }
+        }
 
 /* FIXME: this is rejecting job submits?
       if (pnode->nd_state & pass)
@@ -2331,7 +2342,7 @@ static int search(
       if (!hasprop(pnode,glorf))
         continue;
 
-      if (skip == SKIP_NONE)  
+      if ((skip == SKIP_NONE) || (skip == SKIP_NONE_REUSE))
         {
         if (vpreq > pnode->nd_nsn)
           continue;
@@ -2348,6 +2359,8 @@ static int search(
         continue;
         }
  
+      /* NOTE: allow node re-use if SKIP_NONE_REUSE by ignoring 'thinking' above */
+
       pnode->nd_flag = thinking;
 
       mark(pnode,glorf);
@@ -2380,7 +2393,11 @@ static int search(
     if (pnode->nd_ntype == NTYPE_CLUSTER) 
       {
       if (pnode->nd_flag != thinking)
+        {
+        /* only shuffle nodes which have been selected above */
+
         continue;
+        }
     
       if (pnode->nd_state & pass)
         continue;
@@ -2424,7 +2441,9 @@ static int search(
 
   /* FAILURE */
 
-  return(0);	/* not found */
+  /* not found */
+
+  return(0);	
   }  /* END search() */
 
 
@@ -2619,15 +2638,21 @@ static int listelem(
   struct pbsnode *pnode;
   int	node_req = 1;
 
-  if ((i = number(str, &num)) == -1)	/* get number */
+  if ((i = number(str,&num)) == -1)	/* get number */
     {
+    /* FAILURE */
+
     return(ret);
     }
 
   if (i == 0) 
-    {				/* number exists */
+    {
+    /* number exists */
+
     if (**str == ':') 
-      {		/* there are properties */
+      {
+      /* there are properties */
+
       (*str)++;
 
       if (proplist(str,&prop,&node_req))
@@ -2637,7 +2662,9 @@ static int listelem(
       } 
     }
   else 
-    {					/* no number */
+    {
+    /* no number */
+
     if (proplist(str,&prop,&node_req))
       {
       /* must be a prop list with no number in front */
@@ -2667,22 +2694,45 @@ static int listelem(
         break;		/* found enough  */
         }
       }
-    }
+    }    /* END for (i) */
 
-  if (hit < num)			/* can never be satisfied */
-    goto done;
+  if (hit < num)	
+    {
+    /* request exceeds configured nodes */
+
+    if ((SvrNodeCt == 0) || (SvrNodeCt < num))
+      {
+      /* request exceeds server resources_available */
+
+      /* request can never be satisfied */
+
+      goto done;
+      }
+    }
 
   /*
   ** Find an initial set of nodes to satisfy the request.
-  ** Go ahead and use any nodes no mater what state they are in.
+  ** Go ahead and use any nodes no matter what state they are in.
   */
 
+  /* NOTE:  SKIP_NONE_REUSE will not mark nodes as inuse, ie allow node re-use */
+
   for (i = 0;i < num;i++) 
     {
-    if (search(prop,node_req,SKIP_NONE,order,0))
-      continue;
+    if (SvrNodeCt == 0)
+      {
+      if (search(prop,node_req,SKIP_NONE,order,0))
+        continue;
+      }
+    else
+      {
+      if (search(prop,node_req,SKIP_NONE_REUSE,order,0))
+        continue;
+      }
 
-    goto done;		/* can never be satisfied */
+    /* can never be satisfied */
+
+    goto done;
     }
 
   ret = 1;
@@ -2894,6 +2944,9 @@ int MSNPrintF(
   }  /* END MSNPrintF() */
 
 
+
+
+
 /*
  *	Test a node specification.  
  *
@@ -2932,14 +2985,17 @@ static int node_spec(
 
   if (LOGLEVEL >= 6)
     {
-    sprintf(log_buffer,"entered spec=%.4000s",spec);
-      log_record(
-        PBSEVENT_SCHED,
-        PBS_EVENTCLASS_REQUEST,
-        id,
-        log_buffer);
+    sprintf(log_buffer,"entered spec=%.4000s",
+      spec);
 
-    DBPRT(("%s\n", log_buffer));
+    log_record(
+      PBSEVENT_SCHED,
+      PBS_EVENTCLASS_REQUEST,
+      id,
+      log_buffer);
+
+    DBPRT(("%s\n",
+      log_buffer));
     }
 
   exclusive = 1;	/* by default, nodes (VPs) are requested exclusively */
@@ -3017,7 +3073,7 @@ static int node_spec(
     return(-1);
     }
 
-  if (LOGLEVEL >=6)
+  if (LOGLEVEL >= 6)
     {
     sprintf(log_buffer,"job allocation debug: %d requested, %d svr_clnodes, %d svr_totnodes",
       num,
@@ -3029,7 +3085,8 @@ static int node_spec(
       id,
       log_buffer);
 
-    DBPRT(("%s\n", log_buffer));
+    DBPRT(("%s\n",
+      log_buffer));
     }
 
   /*
@@ -3172,7 +3229,7 @@ static int node_spec(
     return(0);
     }  /* END if ((num > svr_numnodes) && early) */
 
-  if (LOGLEVEL >=6)
+  if (LOGLEVEL >= 6)
     {
     sprintf(log_buffer,"job allocation debug(2): %d requested, %d svr_numnodes",
       num,
@@ -3184,8 +3241,10 @@ static int node_spec(
       id,
       log_buffer);
 
-    DBPRT(("%s\n", log_buffer));
+    DBPRT(("%s\n",
+      log_buffer));
     }
+
   /*
    * 	At this point we know the spec is legal.
    *	Here we find a replacement for any nodes chosen above
@@ -3356,7 +3415,7 @@ static int node_spec(
 
   /* SUCCESS - spec is ok */
 
-  if (LOGLEVEL >=6)
+  if (LOGLEVEL >= 6)
     {
     sprintf(log_buffer,"job allocation debug(3): returning %d requested",
       num);
@@ -3367,7 +3426,8 @@ static int node_spec(
       id,
       log_buffer);
 
-    DBPRT(("%s\n", log_buffer));
+    DBPRT(("%s\n", 
+      log_buffer));
     }
 
   return(num);	
@@ -3477,7 +3537,13 @@ int set_nodes(
       continue;
 
     if (pnode->nd_flag != thinking)
-      continue;			/* skip this one */
+      {
+      /* node is not considered/eligible for job - see search() */
+
+      /* skip node */
+
+      continue;	
+      }
 
     /* within the node, check each subnode */
 
@@ -3584,8 +3650,11 @@ DBPRT(("%s\n",log_buffer));
         log_buffer);
       }
 
+    if (EMsg != NULL)
+      sprintf(EMsg,"no nodes can be allocated to job");
+
     return(PBSE_RESCUNAV);
-    }
+    }  /* END if (hlist == NULL) */
 
   pjob->ji_qs.ji_svrflags |= JOB_SVFLG_HasNodes;  /* indicate has nodes */
 
@@ -3648,10 +3717,11 @@ DBPRT(("%s\n",log_buffer));
 
 /*
  * node_avail_complex - 
- *		*navail is set to number available
- *		*nalloc is set to number allocated
- *		*nresvd is set to number reserved 
- *		*ndown  is set to number down/offline
+ *	*navail is set to number available
+ *	*nalloc is set to number allocated
+ *	*nresvd is set to number reserved 
+ *	*ndown  is set to number down/offline
+ *      return -1 on failure
  */
 
 int node_avail_complex(
