@@ -113,17 +113,16 @@
 #include "tracking.h"
 #include "svrfunc.h"
 #include "acct.h"
-#include "pbs_version.h"
 #include "rpp.h"
 #include "net_connect.h"
 #include "pbs_proto.h"
 #include "batch_request.h"
 
 
-#ifndef SIGKILL
+/*#ifndef SIGKILL*/
 /* there is some weird stuff in gcc include files signal.h & sys/params.h */
 #include <signal.h>
-#endif
+/*#endif*/
 
 #ifndef SUCCESS
 #define SUCCESS 1
@@ -181,13 +180,14 @@ extern char	*path_nodestate;
 extern int	 queue_rank;
 extern char	 server_name[];
 extern int	 svr_delay_entry;
-extern list_head svr_newjobs;
-extern list_head svr_alljobs;
-extern list_head svr_queues;
-extern list_head svr_requests;
-extern list_head task_list_immed;
-extern list_head task_list_timed;
-extern list_head task_list_event;
+extern tlist_head svr_newjobs;
+extern tlist_head svr_alljobs;
+extern tlist_head svr_queues;
+extern tlist_head svr_requests;
+extern tlist_head svr_newnodes;
+extern tlist_head task_list_immed;
+extern tlist_head task_list_timed;
+extern tlist_head task_list_event;
 extern time_t	 time_now;
 
 extern struct server server;
@@ -257,6 +257,8 @@ int pbsd_init(
   struct sigaction act;
   struct sigaction oact;
 
+  extern int TForceUpdate;
+
   /* The following is code to reduce security risks */
 
   if (setup_env(PBS_ENVIRON) == -1) 
@@ -445,6 +447,7 @@ int pbsd_init(
   CLEAR_HEAD(svr_queues);
   CLEAR_HEAD(svr_alljobs);
   CLEAR_HEAD(svr_newjobs);
+  CLEAR_HEAD(svr_newnodes);
 
   time_now = time((time_t *)0);
 
@@ -526,11 +529,18 @@ int pbsd_init(
       {	
       /* path_svrdb exists */
 
-      need_y_response(type);
+      /* will exit on (n)o response */
+
+      if (TForceUpdate == 0)
+        {
+        need_y_response(type);
+        }
+
+      /* (y)es response received */
 
       rm_files(path_priv);
 
-      svr_save(&server, SVR_SAVE_FULL);
+      svr_save(&server,SVR_SAVE_FULL);
       }
     }
 
@@ -538,7 +548,7 @@ int pbsd_init(
     &server.sv_attr[(int)SRV_ATR_version], 
     0, 
     0,
-    PBS_VERSION);
+    PACKAGE_VERSION);
 
   /* 6. open accounting file */
 
@@ -960,6 +970,7 @@ static int pbsd_init_job(
 
   {
   unsigned int d;
+  struct work_task *pwt;
 
   pjob->ji_momhandle = -1;
 
@@ -1044,7 +1055,12 @@ static int pbsd_init_job(
 
       /* resend rtc */
 
-      set_task(WORK_Immed,0,resume_net_move,(void *)pjob);
+      pwt = set_task(WORK_Immed,0,resume_net_move,(void *)pjob);
+
+      if (pwt)
+        {
+        append_link(&pjob->ji_svrtask,&pwt->wt_linkobj,pwt);
+        }
 
       break;
 		
@@ -1072,7 +1088,11 @@ static int pbsd_init_job(
 
       set_resc_assigned(pjob,INCR);
 
-      set_old_nodes(pjob);
+      /* suspended jobs don't get reassigned to nodes */
+      if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_Suspend) == 0)
+        {
+        set_old_nodes(pjob);
+        }
 
       if (type == RECOV_HOT)
         pjob->ji_qs.ji_svrflags |= JOB_SVFLG_HOTSTART;
@@ -1100,7 +1120,12 @@ static int pbsd_init_job(
 
       apply_job_delete_nanny(pjob,time_now + 60);
 
-      set_task(WORK_Immed,0,on_job_exit,(void *)pjob);
+      pwt = set_task(WORK_Immed,0,on_job_exit,(void *)pjob);
+
+      if (pwt)
+        {
+        append_link(&pjob->ji_svrtask,&pwt->wt_linkobj,pwt);
+        }
 
       pbsd_init_reque(pjob,KEEP_STATE);
 
@@ -1111,7 +1136,12 @@ static int pbsd_init_job(
       /* NOOP - completed jobs are already purged above */
       /* for some reason, this doesn't actually work */
 
-      set_task(WORK_Immed,0,on_job_exit,(void *)pjob);
+      pwt = set_task(WORK_Immed,0,on_job_exit,(void *)pjob);
+
+      if (pwt)
+        {
+        append_link(&pjob->ji_svrtask,&pwt->wt_linkobj,pwt);
+        }
 
       pbsd_init_reque(pjob,KEEP_STATE);
 
@@ -1120,7 +1150,14 @@ static int pbsd_init_job(
     case JOB_SUBSTATE_RERUN:
 
       if (pjob->ji_qs.ji_state == JOB_STATE_EXITING)
-        set_task(WORK_Immed,0,on_job_rerun,(void *)pjob);
+        {
+        pwt = set_task(WORK_Immed,0,on_job_rerun,(void *)pjob);
+
+        if (pwt)
+          {
+          append_link(&pjob->ji_svrtask,&pwt->wt_linkobj,pwt);
+          }
+        }
 
       pbsd_init_reque(pjob,KEEP_STATE);
 
@@ -1129,7 +1166,12 @@ static int pbsd_init_job(
     case JOB_SUBSTATE_RERUN1:
     case JOB_SUBSTATE_RERUN2:
 
-      set_task(WORK_Immed,0,on_job_rerun,(void *)pjob);
+      pwt = set_task(WORK_Immed,0,on_job_rerun,(void *)pjob);
+
+      if (pwt)
+        {
+        append_link(&pjob->ji_svrtask,&pwt->wt_linkobj,pwt);
+        }
 
       pbsd_init_reque(pjob,KEEP_STATE);
 
@@ -1199,9 +1241,9 @@ static void pbsd_init_reque(
     {
     /* update the state, typically to some form of QUEUED */
 
-    svr_evaljobstate(pjob, &newstate, &newsubstate, 0);
+    svr_evaljobstate(pjob,&newstate,&newsubstate,0);
 
-    svr_setjobstate(pjob, newstate, newsubstate);
+    svr_setjobstate(pjob,newstate,newsubstate);
     } 
   else 
     {
@@ -1397,6 +1439,11 @@ static int chk_save_file(
   {
   struct stat sb;
 
+  if (*filename == '.')
+    {
+    return(-1);
+    }
+
   if (stat(filename,&sb) == -1)
     {
     return(errno);
@@ -1430,6 +1477,9 @@ static void resume_net_move(
   return;
   }
 
+
+
+
 /*
  * need_y_response - on create/clean initialization that would delete
  *	information, obtain the operator approval first.
@@ -1451,9 +1501,9 @@ static void need_y_response(
   fflush(stdin);
 
   if (type == RECOV_CREATE)
-    printf(msg_startup3, msg_daemonname, server_name, "Create","server database");
+    printf(msg_startup3,msg_daemonname,server_name,"Create","server database");
   else
-    printf(msg_startup3, msg_daemonname, server_name, "Cold", "jobs");
+    printf(msg_startup3,msg_daemonname,server_name,"Cold","jobs");
   
   while (1) 
     {
@@ -1494,7 +1544,7 @@ static void need_y_response(
     }
 
   return;
-  }
+  }  /* END need_y_response() */
 
 
 
