@@ -172,7 +172,7 @@ extern char    *msg_daemonname;
 extern int	pbs_errno;
 char	       *pbs_o_host = "PBS_O_HOST";
 pbs_net_t	pbs_mom_addr;
-unsigned int	pbs_mom_port;
+unsigned int	pbs_mom_port = 0;
 unsigned int	pbs_rm_port;
 pbs_net_t	pbs_scheduler_addr;
 unsigned int	pbs_scheduler_port;
@@ -410,6 +410,7 @@ int main(
   uint	 tryport;
   char	 lockfile[MAXPATHLEN + 1];
   char	*pc;
+  char  *ptr;
   job	*pjob;
   pbs_queue *pque;
   char	*servicename = NULL;
@@ -420,9 +421,9 @@ int main(
   time_t last_jobstat_time;
   int    when;
 
-  void	 ping_nodes A_((struct work_task *ptask));
-  void   check_nodes A_((struct work_task *ptask));
-  void   check_log A_((struct work_task *ptask));
+  void ping_nodes A_((struct work_task *));
+  void check_nodes A_((struct work_task *));
+  void check_log A_((struct work_task *));
 
   static struct {
     char *it_name;
@@ -477,17 +478,65 @@ int main(
 
   /* initialize service port numbers for self, Scheduler, and MOM */
 
-  pbs_server_port_dis = get_svrport(PBS_BATCH_SERVICE_NAME,"tcp", 
-    PBS_BATCH_SERVICE_PORT_DIS);
+  ptr = getenv("PBS_BATCH_SERVICE_PORT");
 
-  pbs_scheduler_port = get_svrport(PBS_SCHEDULER_SERVICE_NAME,"tcp",
-    PBS_SCHEDULER_SERVICE_PORT);
+  if (ptr != NULL)
+    {
+    pbs_server_port_dis = (int)strtol(ptr,NULL,10);
+    }
 
-  pbs_mom_port = get_svrport(PBS_MOM_SERVICE_NAME,"tcp",
-    PBS_MOM_SERVICE_PORT);
+  if (pbs_server_port_dis <= 0)
+    {
+    pbs_server_port_dis = get_svrport(
+      PBS_BATCH_SERVICE_NAME,
+      "tcp", 
+      PBS_BATCH_SERVICE_PORT_DIS);
+    }
 
-  pbs_rm_port = get_svrport(PBS_MANAGER_SERVICE_NAME,"tcp",
-    PBS_MANAGER_SERVICE_PORT);
+  ptr = getenv("PBS_SCHEDULER_SERVICE_PORT");
+
+  if (ptr != NULL)
+    {
+    pbs_scheduler_port = (int)strtol(ptr,NULL,10);
+    }
+
+  if (pbs_scheduler_port <= 0)
+    { 
+    pbs_scheduler_port = get_svrport(
+      PBS_SCHEDULER_SERVICE_NAME,
+      "tcp",
+      PBS_SCHEDULER_SERVICE_PORT);
+    }
+
+  ptr = getenv("PBS_MOM_SERVICE_PORT");
+
+  if (ptr != NULL)
+    {
+    pbs_mom_port = (int)strtol(ptr,NULL,10);
+    }
+
+  if (pbs_mom_port <= 0)
+    { 
+    pbs_mom_port = get_svrport(
+      PBS_MOM_SERVICE_NAME,
+      "tcp",
+      PBS_MOM_SERVICE_PORT);
+    }
+
+  ptr = getenv("PBS_MANAGER_SERVICE_PORT");
+
+  if (ptr != NULL)
+    {
+    pbs_rm_port = (int)strtol(ptr,NULL,10);
+    }
+
+  if (pbs_rm_port <= 0)
+    {
+    pbs_rm_port = get_svrport(
+      PBS_MANAGER_SERVICE_NAME,
+      "tcp",
+      PBS_MANAGER_SERVICE_PORT);
+    }
 
   strcpy(server_name,server_host);	/* by default server = host */
 
@@ -725,6 +774,8 @@ int main(
 
       case 'S':
 
+        /* FORMAT: ??? */
+
         if (get_port(
               optarg, 
               &pbs_scheduler_port,
@@ -1241,18 +1292,20 @@ static int get_port(
     {
     name = parse_servername(arg,port);
 
-    if (name != NULL) 
-      {
-      *addr = get_hostaddr(name);
-      } 
-    else 
+    if (name == NULL) 
       {
+      /* FAILURE */
+
       return(-1);
       }
+
+    *addr = get_hostaddr(name);
     }
 
   if ((*port <= 0) || (*addr == 0))
     {
+    /* FAILURE */
+
     return(-1);
     }
 
