@@ -227,6 +227,9 @@ int svr_movejob(
   }  /* svr_movejob() */
 
 
+
+
+
 /*
  * local_move - internally move a job to another queue
  *
@@ -240,7 +243,7 @@ int svr_movejob(
 
 static int local_move(
 
-  job *jobp,
+  job                  *jobp,
   struct batch_request *req)
 
   {
@@ -279,21 +282,21 @@ static int local_move(
     } 
   else 
     {
-    mtype = MOVE_TYPE_Move;		/* non-privileged move */
+    mtype = MOVE_TYPE_Move;	/* non-privileged move */
     }
 
   if ((pbs_errno = svr_chkque(
         jobp,
         qp,
-        get_variable(jobp,pbs_o_host),mtype)))
+        get_variable(jobp,pbs_o_host),mtype,NULL)))
     {
     /* should this queue be retried? */
 
     return(should_retry_route(pbs_errno));
     }
 
-  /* dequeue job from present queue, update destination and	*/
-  /* queue_rank for new queue and enqueue into destination	*/
+  /* dequeue job from present queue, update destination and */
+  /* queue_rank for new queue and enqueue into destination  */
 
   svr_dequejob(jobp);
 
@@ -301,7 +304,9 @@ static int local_move(
 
   jobp->ji_wattr[(int)JOB_ATR_qrank].at_val.at_long = ++queue_rank;
 
-  if ((pbs_errno = svr_enquejob(jobp)))
+  pbs_errno = svr_enquejob(jobp);
+
+  if (pbs_errno != 0)
     {
     return(-1);	/* should never ever get here */
     }
@@ -395,7 +400,7 @@ static void post_routejob(
       /* force re-eval of job state out of Transit */
 
       svr_evaljobstate(jobp,&newstate,&newsub,1);
-      svr_setjobstate(jobp, newstate, newsub);
+      svr_setjobstate(jobp,newstate,newsub);
 
       if ((r = job_route(jobp)) == PBSE_ROUTEREJ)
         job_abt(&jobp,msg_routebad);
@@ -403,7 +408,7 @@ static void post_routejob(
         job_abt(&jobp,msg_routexceed);
 
       break;
-    }  /* END switch(r) */
+    }  /* END switch (r) */
 
   return;
   }  /* END post_routejob() */
@@ -463,28 +468,45 @@ static void post_movejob(
     log_err(-1,id,log_buffer);
     }
 
-	if (WIFEXITED(stat)) {
-		r = WEXITSTATUS(stat);
+  if (WIFEXITED(stat)) 
+    {
+    r = WEXITSTATUS(stat);
 
-		if (r == 0) {	/* purge server's job structure */
-			if (jobp->ji_qs.ji_svrflags & JOB_SVFLG_StagedIn)
-				remove_stagein(jobp);
-			(void)strcpy(log_buffer, msg_movejob);
-			(void)sprintf(log_buffer+strlen(log_buffer),
-				      msg_manager, 
-				      req->rq_ind.rq_move.rq_destin,
-				      req->rq_user, req->rq_host);
-			job_purge(jobp);
-		} else
-			r = PBSE_ROUTEREJ;
-	}
-	else {
-		r = PBSE_SYSTEM;
-		(void)sprintf(log_buffer, msg_badexit, stat);
-		(void)strcat(log_buffer, id);
-		log_event(PBSEVENT_SYSTEM, PBS_EVENTCLASS_JOB,
-			  jobp->ji_qs.ji_jobid, log_buffer);
-	}
+    if (r == 0) 
+      {
+      /* purge server's job structure */
+
+      if (jobp->ji_qs.ji_svrflags & JOB_SVFLG_StagedIn)
+        remove_stagein(jobp);
+
+      strcpy(log_buffer,msg_movejob);
+
+      sprintf(log_buffer + strlen(log_buffer),msg_manager, 
+        req->rq_ind.rq_move.rq_destin,
+        req->rq_user, 
+        req->rq_host);
+
+      job_purge(jobp);
+      } 
+    else
+      {
+      r = PBSE_ROUTEREJ;
+      }
+    }
+  else 
+    {
+    r = PBSE_SYSTEM;
+
+    sprintf(log_buffer,msg_badexit,stat);
+
+    strcat(log_buffer,id);
+
+    log_event(
+      PBSEVENT_SYSTEM, 
+      PBS_EVENTCLASS_JOB,
+      jobp->ji_qs.ji_jobid, 
+      log_buffer);
+    }
 
   if (r) 
     {
@@ -535,7 +557,7 @@ int send_job(
   void	    *data)	/* ptr to optional batch_request to be put */
 			/* in the work task structure */
   {
-  list_head	 attrl;
+  tlist_head	 attrl;
   enum conn_type cntype = ToServerDIS;
   int		 con;
   char		*destin = jobp->ji_qs.ji_destin;
@@ -860,7 +882,7 @@ int send_job(
 
       if (jobp->ji_qs.ji_svrflags & JOB_SVFLG_SCRIPT) 
         {
-        if (PBSD_jscript(con,script_name) != 0)
+        if (PBSD_jscript(con,script_name,jobp->ji_qs.ji_jobid) != 0)
           continue;
         }
 
@@ -1087,7 +1109,7 @@ int net_move(
     data      = 0;
     }
 
-  svr_setjobstate(jobp, JOB_STATE_TRANSIT, JOB_SUBSTATE_TRNOUT);
+  svr_setjobstate(jobp,JOB_STATE_TRANSIT,JOB_SUBSTATE_TRNOUT);
 
   return(send_job(
     jobp, 
@@ -1096,7 +1118,7 @@ int net_move(
     move_type, 
     post_func, 
     data));
-  }
+  }  /* END net_move() */
 
 
 
@@ -1126,6 +1148,7 @@ static int should_retry_route(
     case PBSE_INTERNAL:
     case PBSE_EXPIRED:
     case PBSE_MAXQUED:
+    case PBSE_MAXUSERQUED:
     case PBSE_QUNOENB:
     case PBSE_NOCONNECTS:
 
